API Reference
=============

Converter high-level API
------------------------------

.. automodule:: converter
    :members:

Container formats
-----------------

.. automodule:: converter.formats
    :members:

Audio and video codecs
----------------------

.. automodule:: converter.avcodecs
    :members:

Low-level ffmpeg wrapper
------------------------

.. automodule:: converter.ffmpeg
    :members:
